/*----------------------------------------------------------------------*
 * Example sketch for Arduino Button Library by Jack Christensen        *
 *                                                                      *
 * The simplest example. Using a tactile button switch to turn          *
 * the Arduino's pin 13 LED on and off. Wire a switch from Arduino      *
 * pin 2 to ground.                                                     *
 *                                                                      *
 * This work is licensed under the Creative Commons Attribution-        *
 * ShareAlike 3.0 Unported License. To view a copy of this license,     *
 * visit http://creativecommons.org/licenses/by-sa/3.0/ or send a       *
 * letter to Creative Commons, 171 Second Street, Suite 300,            *
 * San Francisco, California, 94105, USA.                               *
 *----------------------------------------------------------------------*/

#include <Button_JC.h>        //https://github.com/JChristensen/Button
                           //                                                                           /--D6
#define BUTTON_PIN 6       // Connect a tactile button switch (or something similar):  +5V -- switch --/ resistor -- GND
                           // from Arduino pin 6 to a resistor and switch so the switch pulls the port D6 to a HIGH when pressed.
#define PULLUP false       // To keep things simple, we coulld use the Arduino's internal pullup resistor, but not for now.
#define INVERT false       // Since the pulldown resistor will keep the pin low unless the
                           // switch is closed, this is positive logic, i.e. a low state
                           // means the button is NOT pressed. (Assuming a normally open switch.)
#define DEBOUNCE_MS 20     // A debounce time of 20 milliseconds usually works well for tactile button switches.
#define LED_PIN 13         // The standard Arduino "Pin 13" LED

Button_JC myBtn(BUTTON_PIN, PULLUP, INVERT, DEBOUNCE_MS);    //Declare the button
boolean ledState;          //A variable that keeps the current LED status

//====================================================================
void setup(void)
{
    pinMode(LED_PIN, OUTPUT);    //Set the LED pin as an output
}

//====================================================================
void loop(void)
{
    myBtn.read();                    //Read the button

    if (myBtn.wasReleased()) {       //If the button was released, change the LED state
        ledState = !ledState;
        digitalWrite(LED_PIN, ledState);
    }
}


